package com.me.pacman.level;

import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.TextureRegion;
import com.me.pacman.PacDude;

public class Level {

    // Grid of components, [rows][columns]
    public LevelComponent[][] components;

    public Level(String level) {
        LevelLoader loader = new LevelLoader(level);
        components = loader.loadLevel();
    }

    public void render(PacDude game, int offsetX, int offsetY) {
        Texture sprites = game.assets.get("sprites/sprites_1.png");
        TextureRegion powerPellet = new TextureRegion(sprites, 16, 16, 8, 8);
        TextureRegion pellet = new TextureRegion(sprites, 24, 16, 8, 8);

        for (int i = 0; i < components.length; i++) {
            LevelComponent[] row = components[i];
            for (int j = 0; j < row.length; j++) {
                LevelComponent component = row[j];
                TextureRegion sprite;
                switch (component) {
                    case PELLET:
                        sprite = pellet;
                        break;
                    case POWER_PELLET:
                        sprite = powerPellet;
                        break;
                    default:
                        continue;
                }
                game.batch.draw(sprite, (j * 8) + offsetX + 8, (i * 8) + offsetY + 8);
            }
        }
    }

}
